@@ -8,6 +8,7 @@ import os
 import subprocess
 from xyw_macro.win32 import send_kb_event, send_unicode
 from xyw_macro.hook import VK
+from xyw_macro.contants import SLEEP_TIME
 
 
 def press_key(v_key):
@@ -38,7 +39,7 @@ def touch_key(v_key):
     release_key(v_key)
 
 
-def random_sleep(seconds, range_percent=None):
+def random_sleep(seconds=SLEEP_TIME, range_percent=None):
     """
     睡眠指定秒数，随机浮动指定比例
     :param seconds: 睡眠时间，单位s
@@ -68,7 +69,6 @@ def get_clipboard_files():
     """
     press_copy()
     if win32clipboard.IsClipboardFormatAvailable(win32con.CF_HDROP) == 0:
-        print('no')
         return
     win32clipboard.OpenClipboard()
     data = win32clipboard.GetClipboardData(win32con.CF_HDROP)
